@@ -137,7 +137,7 @@ class DynamoDbCoreAdapter:
         try:
             table = self.dynamodb.Table(self.table_name)
             response = table.get_item(**kwargs)
-            if "Item" in response:
+            if 'Item' in response:
                 processed_item = DynamoDBUtils.dynamodb_to_python_higher_level(dynamodb_object=response['Item'])
                 return GetItemResponse(item=processed_item, success=True)
             else:
@@ -169,31 +169,31 @@ class DynamoDbCoreAdapter:
 
     def add_data_elements_to_list(self, index_name: str, key_value: Any, object_path: str, element_values: List[dict]) -> Optional[Response]:
         kwargs = {
-            "TableName": self.table_name,
-            "Key": {index_name: key_value},
-            "ReturnValues": "UPDATED_NEW",
-            "UpdateExpression": f"SET {object_path} = list_append(if_not_exists({object_path}, :emptyList), :newItems)",
+            'TableName': self.table_name,
+            'Key': {index_name: key_value},
+            'ReturnValues': "UPDATED_NEW",
+            'UpdateExpression': f"SET {object_path} = list_append(if_not_exists({object_path}, :emptyList), :newItems)",
             # The if_not_exists inside the list_append, will create an empty
             # list before adding the newItems, only if the field do not exist.
-            "ExpressionAttributeValues": {
-                ":newItems": element_values,
-                ":emptyList": []
+            'ExpressionAttributeValues': {
+                ':newItems': element_values,
+                ':emptyList': []
             }
         }
         return self._execute_update_query(query_kwargs_dict=kwargs)
 
     def remove_data_elements_from_list(self, index_name: str, key_value: Any, list_object_path: str, indexes_to_remove: list) -> Optional[Response]:
         kwargs = {
-            "TableName": self.table_name,
-            "Key": {index_name: key_value},
-            "ReturnValues": "UPDATED_NEW"
+            'TableName': self.table_name,
+            'Key': {index_name: key_value},
+            'ReturnValues': "UPDATED_NEW"
         }
         update_expression = "REMOVE "
         for i, index_in_database_list in enumerate(indexes_to_remove):
             update_expression += f"{list_object_path}[{index_in_database_list}]"
             if i + 1 < len(indexes_to_remove):
                 update_expression += ", "
-        kwargs["UpdateExpression"] = update_expression
+        kwargs['UpdateExpression'] = update_expression
 
         return self._execute_update_query(query_kwargs_dict=kwargs)
 
@@ -245,7 +245,7 @@ class DynamoDbCoreAdapter:
         # Even if we return an empty output_response_attributes dict, we do not want to return None instead of a dict, because since this function only returns a dict, a return
         # value of None indicates that the operation failed. Where as, for example in delete operation, we will not request the removed attributes from the database, which will
         # give us an empty output_response_attributes dict, but the delete operation will base itself on the presence of the dict to judge if the operation failed or not.
-        output_response_attributes: Dict[str, Any] = DynamoDBUtils.dynamodb_to_python_higher_level(response.attributes) if response.attributes is not None else {}
+        output_response_attributes: dict = DynamoDBUtils.dynamodb_to_python_higher_level(response.attributes) if response.attributes is not None else {}
         if len(targets_path_elements) == len(consumed_targets_path_elements):
             return output_response_attributes
         else:
@@ -258,8 +258,8 @@ class DynamoDbCoreAdapter:
                 retrieve_removed_elements=retrieve_removed_elements
             )
             combined_output_response_attributes = {
-                **(output_response_attributes or dict()),
-                **(request_continuation_response_attributes or dict())
+                **(output_response_attributes or {}),
+                **(request_continuation_response_attributes or {})
             }
             return combined_output_response_attributes
 
@@ -354,10 +354,10 @@ class DynamoDbCoreAdapter:
         return response
 
     def _construct_update_data_element_to_map_query_kwargs(
-            self, index_name: str, key_value: Any, field_path_elements: List[DatabasePathElement], value: Any
+            self, index_name: str, key_value: Any, field_path_elements: List[DatabasePathElement], value: Any, return_old_value: bool = False
     ) -> dict:
 
-        expression_attribute_names_dict = {}
+        expression_attribute_names_dict: Dict[str, str] = {}
         update_expression = "SET "
 
         for i, path_element in enumerate(field_path_elements):
@@ -372,7 +372,7 @@ class DynamoDbCoreAdapter:
         update_query_kwargs = {
             "TableName": self.table_name,
             "Key": {index_name: key_value},
-            "ReturnValues": "UPDATED_NEW",
+            "ReturnValues": "NONE" if return_old_value is not True else "UPDATED_OLD",
             "UpdateExpression": update_expression,
             "ExpressionAttributeNames": expression_attribute_names_dict,
             "ExpressionAttributeValues": {
@@ -382,14 +382,14 @@ class DynamoDbCoreAdapter:
         return update_query_kwargs
 
     def set_update_data_element_to_map_with_default_initialization(
-            self, index_name: str, key_value: Any, field_path_elements: List[DatabasePathElement], value: Any
+            self, index_name: str, key_value: Any, field_path_elements: List[DatabasePathElement], value: Any, return_old_value: bool = False
     ) -> Optional[Response]:
         update_query_kwargs = self._construct_update_data_element_to_map_query_kwargs(
-            index_name=index_name, key_value=key_value, field_path_elements=field_path_elements, value=value
+            index_name=index_name, key_value=key_value, field_path_elements=field_path_elements, value=value, return_old_value=return_old_value
         )
         return self._execute_update_query_with_initialization_if_missing(
             index_name=index_name, key_value=key_value, update_query_kwargs=update_query_kwargs,
-            setters=[FieldPathSetter(field_path_elements=field_path_elements, value_to_set=value)]
+            setters=[FieldPathSetter(field_path_elements=field_path_elements, value_to_set=value)],
         )
 
     def set_update_data_element_to_map_without_default_initialization(
@@ -498,7 +498,7 @@ class DynamoDbCoreAdapter:
         return response
 
     def set_update_multiple_data_elements_to_map(
-            self, index_name: str, key_value: Any, setters: List[FieldPathSetter]
+            self, index_name: str, key_value: Any, setters: List[FieldPathSetter], return_old_values: bool
     ) -> Optional[Response]:
 
         if not len(setters) > 0:
@@ -507,17 +507,17 @@ class DynamoDbCoreAdapter:
             return None
 
         update_query_kwargs = {
-            "TableName": self.table_name,
-            "Key": {index_name: key_value},
-            "ReturnValues": "UPDATED_NEW"
+            'TableName': self.table_name,
+            'Key': {index_name: key_value},
+            'ReturnValues': "UPDATED_OLD" if return_old_values is True else "NONE"
         }
         update_expression = "SET "
-        expression_attribute_names_dict, expression_attribute_values_dict = {}, dict()
+        expression_attribute_names_dict, expression_attribute_values_dict = {}, {}
 
         consumed_setters: List[FieldPathSetter] = []
         for i_setter, current_setter in enumerate(setters):
             current_setter_update_expression = ""
-            current_setter_attribute_names, current_setter_attribute_values = {}, dict()
+            current_setter_attribute_names, current_setter_attribute_values = {}, {}
             for i_path, current_path_element in enumerate(current_setter.field_path_elements):
                 current_path_key = f"#setter{i_setter}_pathKey{i_path}"
                 current_setter_update_expression, new_expression_attribute_names = DynamoDbCoreAdapter._add_database_path_element_to_string_expression(
@@ -559,10 +559,10 @@ class DynamoDbCoreAdapter:
                 ))
                 break
 
-        update_query_kwargs["UpdateExpression"] = update_expression
-        update_query_kwargs["ExpressionAttributeValues"] = expression_attribute_values_dict
+        update_query_kwargs['UpdateExpression'] = update_expression
+        update_query_kwargs['ExpressionAttributeValues'] = expression_attribute_values_dict
         if len(expression_attribute_names_dict) > 0:
-            update_query_kwargs["ExpressionAttributeNames"] = expression_attribute_names_dict
+            update_query_kwargs['ExpressionAttributeNames'] = expression_attribute_names_dict
 
         response = self._execute_update_query_with_initialization_if_missing(
             index_name=index_name, key_value=key_value,
@@ -573,7 +573,10 @@ class DynamoDbCoreAdapter:
         else:
             for setter in consumed_setters:
                 setters.remove(setter)
-            return self.set_update_multiple_data_elements_to_map(index_name=index_name, key_value=key_value, setters=setters)
+            return self.set_update_multiple_data_elements_to_map(
+                index_name=index_name, key_value=key_value,
+                setters=setters, return_old_values=return_old_values
+            )
 
     def query_response_by_key(
             self, index_name: str, key_value: Any,
