@@ -1,7 +1,8 @@
-from typing import Optional, List, Dict, Any
+from typing import Optional, List, Dict, Any, Tuple
 
 from StructNoSQL import PrimaryIndex
-from StructNoSQL.models import DatabasePathElement, FieldGetter, FieldSetter, UnsafeFieldSetter, FieldRemover
+from StructNoSQL.models import DatabasePathElement, FieldGetter, FieldSetter, UnsafeFieldSetter, FieldRemover, \
+    FieldPathSetter
 from StructNoSQL.practical_logger import message_with_vars
 from StructNoSQL.tables.base_caching_table import BaseCachingTable
 from StructNoSQL.middlewares.inoft_vocal_engine.inoft_vocal_engine_table_connectors import InoftVocalEngineTableConnectors
@@ -24,12 +25,14 @@ class InoftVocalEngineCachingTable(BaseCachingTable, InoftVocalEngineTableConnec
 
     def commit_update_operations(self) -> bool:
         for primary_key_value, dynamodb_setters in self._pending_update_operations_per_primary_key.items():
-            return self._set_update_multiple_data_elements_to_map(key_value=primary_key_value, setters=list(dynamodb_setters.values()))
+            self._set_update_multiple_data_elements_to_map(key_value=primary_key_value, setters=list(dynamodb_setters.values()))
+        self._pending_update_operations_per_primary_key = {}
         return True  # todo: create a real success status instead of always True
 
     def commit_remove_operations(self) -> bool:
         for primary_key_value, fields_path_elements in self._pending_remove_operations_per_primary_key.items():
-            return self._remove_data_elements_from_map(key_value=primary_key_value, fields_path_elements=list(fields_path_elements.values()))
+            self._remove_data_elements_from_map(key_value=primary_key_value, fields_path_elements=list(fields_path_elements.values()))
+        self._pending_remove_operations_per_primary_key = {}
         return True  # todo: create a real success status instead of always True
 
     def commit_operations(self):
@@ -94,9 +97,26 @@ class InoftVocalEngineCachingTable(BaseCachingTable, InoftVocalEngineTableConnec
     def update_field(self, key_value: str, field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None) -> bool:
         return self._update_field(key_value=key_value, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
 
+    def update_field_return_old(self, key_value: str, field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None) -> Tuple[bool, Optional[Any]]:
+        def middleware(field_path_elements: List[DatabasePathElement], validated_data: Any) -> Tuple[bool, Optional[Any]]:
+            update_success, response_attributes = self._set_update_data_element_to_map_with_default_initialization_return_old(
+                key_value=key_value, value=validated_data,
+                field_path_elements=field_path_elements
+            )
+            return update_success, response_attributes
+        return self._update_field_return_old(middleware=middleware, key_value=key_value, field_path=field_path, value_to_set=value_to_set, query_kwargs=query_kwargs)
+
     def update_multiple_fields(self, key_value: str, setters: List[FieldSetter or UnsafeFieldSetter]) -> bool:
         return self._update_multiple_fields(key_value=key_value, setters=setters)
 
+    def update_multiple_fields_return_old(self, key_value: str, setters: Dict[str, FieldSetter]) -> Tuple[bool, Dict[str, Optional[Any]]]:
+        def middleware(dynamodb_setters: Dict[str, FieldPathSetter]) -> Tuple[bool, dict]:
+            update_success, response_attributes = self._set_update_multiple_data_elements_to_map_return_old(
+                key_value=key_value, setters=list(dynamodb_setters.values())
+            )
+            return update_success, response_attributes
+        return self._update_multiple_fields_return_old(middleware=middleware, key_value=key_value, setters=setters)
+
     def remove_field(self, key_value: str, field_path: str, query_kwargs: Optional[dict] = None) -> Optional[Any]:
         def middleware(fields_path_elements: List[List[DatabasePathElement]]):
             return self._remove_data_elements_from_map(key_value=key_value, fields_path_elements=fields_path_elements)
