@@ -159,7 +159,7 @@ class BaseBasicTable(BaseTable):
         )
 
     def _update_field(
-            self, middleware: Callable[[List[DatabasePathElement], Any], Any],
+            self, middleware: Callable[[List[DatabasePathElement], Any], bool],
             field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None
     ) -> bool:
         validated_data, valid, field_path_elements = process_validate_data_and_make_single_rendered_database_path(
@@ -169,8 +169,27 @@ class BaseBasicTable(BaseTable):
             return middleware(field_path_elements, validated_data)
         return False
 
+    def _update_field_return_old(
+            self, middleware: Callable[[List[DatabasePathElement], Any], Tuple[bool, Any]],
+            field_path: str, value_to_set: Any, query_kwargs: Optional[dict] = None
+    ) -> Tuple[bool, Optional[Any]]:
+        validated_data, valid, field_path_elements = process_validate_data_and_make_single_rendered_database_path(
+            field_path=field_path, fields_switch=self.fields_switch, query_kwargs=query_kwargs, data_to_validate=value_to_set
+        )
+        if valid is True and field_path_elements is not None:
+            update_success, response_attributes = middleware(field_path_elements, validated_data)
+
+            from StructNoSQL.utils.data_processing import navigate_into_data_with_field_path_elements
+            old_item_data: Optional[Any] = navigate_into_data_with_field_path_elements(
+                data=response_attributes, field_path_elements=field_path_elements,
+                num_keys_to_navigation_into=len(field_path_elements)
+            ) if response_attributes is not None else None
+
+            return update_success, old_item_data
+        return False, None
+
     def _update_multiple_fields(
-            self, middleware: Callable[[List[FieldPathSetter]], Any],
+            self, middleware: Callable[[List[FieldPathSetter]], bool],
             setters: List[FieldSetter or UnsafeFieldSetter]
     ) -> bool:
         dynamodb_setters: List[FieldPathSetter] = []
@@ -208,8 +227,36 @@ class BaseBasicTable(BaseTable):
                     field_path_elements=rendered_field_path_elements,
                     value_to_set=processed_value_to_set
                 ))"""
-        response = middleware(dynamodb_setters)
-        return True if response is not None else False
+        update_success: bool = middleware(dynamodb_setters)
+        return update_success
+
+    def _update_multiple_fields_return_old(
+            self, middleware: Callable[[Dict[str, FieldPathSetter]], Tuple[bool, Dict[str, Optional[Any]]]], setters: Dict[str, FieldSetter]
+    ) -> Tuple[bool, Dict[str, Optional[Any]]]:
+
+        dynamodb_setters: Dict[str, FieldPathSetter] = {}
+        for setter_key, setter_item in setters.items():
+            validated_data, valid, field_path_elements = process_validate_data_and_make_single_rendered_database_path(
+                field_path=setter_item.field_path, fields_switch=self.fields_switch,
+                query_kwargs=setter_item.query_kwargs, data_to_validate=setter_item.value_to_set
+            )
+            if valid is True:
+                dynamodb_setters[setter_key] = FieldPathSetter(
+                    field_path_elements=field_path_elements, value_to_set=validated_data
+                )
+        update_success, setters_response_attributes = middleware(dynamodb_setters)
+
+        from StructNoSQL.utils.data_processing import navigate_into_data_with_field_path_elements
+        output: Dict[str, Optional[Any]] = {
+            setter_key: navigate_into_data_with_field_path_elements(
+                data=setters_response_attributes, field_path_elements=setter_item.field_path_elements,
+                num_keys_to_navigation_into=len(setter_item.field_path_elements)
+            ) for setter_key, setter_item in dynamodb_setters.items()
+        } if setters_response_attributes is not None else (
+            {setter_key: None for setter_key in dynamodb_setters.keys()}
+        )
+
+        return update_success, output
 
     def _base_removal(
             self, middleware: Callable[[List[List[DatabasePathElement]]], Any],
